@@ -218,10 +218,9 @@ static inline id parseQText(NGMailAddressParser *self, BOOL _guessMode) {
       returnValue = yesNum;
     }
     else {
-      NSCAssert(length > 0, @"no qtext with length=0");
+      //NSCAssert(length > 0, @"no qtext with length=0");
       returnValue = [mkStrObj(text, length) autorelease];
-      NSCAssert([returnValue isKindOfClass:StrClass],
-               @"got no string ..");
+      //NSCAssert([returnValue isKindOfClass:StrClass], @"got no string ..");
     }
   }
   else {
@@ -470,7 +469,7 @@ static inline id parseDomainLiteral(NGMailAddressParser *self, BOOL _guessMode)
           addrEnd = commaPos;
 
     /* setup for next run */
-    if (addrEnd != NSNotFound && addrEnd+1 < [remainder length]-1)
+    if (addrEnd != NSNotFound && [remainder length] > 0 && addrEnd+1 < [remainder length]-1)
       remainder =
         (NSMutableString *)[remainder substringFromIndex: addrEnd+1];
     else
